LOGICAL FUNCTION READPRI(IU, PRI)
!
! Read a single PRI from the integer Raw IQ file and return the complex I/Q values 
!
! Return value is TRUE if there is some problem, such as EOF
!
! 16 bit integers are in the file as high byte first (Big Endian)
! An offset value is applied to each range gate to prevent a value
! of precisely 0 from getting into log() functions
!
! This routine assumes that the SCT and PCT have already been read 
! and the relevant elements loaded into the PRI structure
!
!
IMPLICIT NONE
INCLUDE 'pct.f90'
INCLUDE 'pri.f90'
!
COMPLEX,PARAMETER :: CZero=(0.0, 0.0) 
!
INTEGER :: IU,IERR,RGT,IRX
INTEGER(KIND=4) :: A,B
! These equivalanced arrays are used to swap the bytes in the I/Q bytes
! because these i86 systems use little endian and the data are in big endian
! In theory the TRANSFER() intrinsic can be used to do this, but it will be slower
! and the intinisic is obtuse.
!
INTEGER(KIND=2),DIMENSION(2)::IPQ
INTEGER(KIND=1),DIMENSION(4)::IBP
EQUIVALENCE (IPQ(1),IBP(1))

INTEGER(KIND=4),DIMENSION(2)::IPQQ
INTEGER(KIND=1),DIMENSION(8)::IBPP
EQUIVALENCE (IPQQ(1),IBPP(1))
!
!
TYPE(PRItype) :: PRI
!
! =============================================
!
!
IERR=0
READPRI=.FALSE.
!
! Get the Ascan data
!write(750,'(a,i4,a,i4)') "PRI%GateCount: ",PRI%GateCount,",PRI%ReceiverCount: ",PRI%ReceiverCount
DO RGT = 1, PRI%GateCount
   DO IRX = 1, PRI%ReceiverCount
!      READ(IU,IOSTAT=IERR) IBPP(2),IBPP(1),IBPP(4),IBPP(3),IBPP(6),IBPP(5),IBPP(8),IBPP(7)
      !READ(IU,IOSTAT=IERR) IBP(1),IBP(2),IBP(3),IBP(4) !iwasaki-k
!      READ(IU,IOSTAT=IERR) PRI%Ascan(IRX,RGT)
       READ(IU,IOSTAT=IERR) A,B
!      WRITE(*,*)    A,B
      IF (IERR.NE.0) THEN
         READPRI=.TRUE.
         RETURN
      ENDIF 
      PRI%Ascan(IRX,RGT)= CMPLX(REAL(A),REAL(B))
!      WRITE(*,*)    PRI%Ascan(IRX,RGT)
      IF (PRI%Ascan(IRX,RGT).EQ.CZero) PRI%Ascan(IRX,RGT)= (1.0,0.0)  
!      write(*,100) RGT, PRI%RangeTable(RGT),IRX,IPQ(1),IPQ(2),PRI%Ascan(IRX,RGT)
   ENDDO
ENDDO
      
RETURN
! 100 FORMAT (I6,1X,F6.1,I3,1X,2I8,2X,2F8.1)
END FUNCTION READPRI 
