SUBROUTINE AMPHASE(DEBUG, PRI)
!
! Compute Amplitude and Phase from I/Q data
!
! Author: Tery Bullett,   University of Colorado CIRES
! 21Feb15 
! Linux using gfortran compiler
!
! License:
! This software is the intellectual property of the author.
! Please respect this.
! Generous terms of use are likely if you ask nicely.
!
! Purpose:
! "To give glory to God by exploring His universe with reverence"  
!
IMPLICIT NONE
INCLUDE 'type-param.f90'! Global Types and parameter definitions 
INCLUDE 'pct.f90'   ! PCT
INCLUDE 'pri.f90'   ! PRI
!
! Arguments
LOGICAL,INTENT(IN)::DEBUG
TYPE(PRItype),INTENT(INOUT) :: PRI
!
! Local Variables
INTEGER IRG,IRX
REAL RI,RQ

! Compute amplitude (dB) and phase (radians) for each range gate and receiver
IF(DEBUG) WRITE(*,*) "AMPPHASE"
IF(DEBUG) WRITE(*,100)'#','IRG','IRX',('I',IRX,'Q',IRX,'A',IRX,'P',IRX,IRX=1,8) 
DO IRG=1,PRI%GateCount
!
   DO IRX = 1, PRI%ReceiverCount
      RI=REAL( PRI%Ascan(IRX,IRG))
      RQ=AIMAG(PRI%Ascan(IRX,IRG))  
      PRI%Amplitude(IRX,IRG)=ABS(PRI%Ascan(IRX,IRG))
      PRI%AmpdB(IRX,IRG)=20.*LOG10(PRI%Amplitude(IRX,IRG))
      PRI%Phase(IRX,IRG)=ATAN2(RQ,RI)
   ENDDO
   IF(DEBUG) WRITE(*,101) IRG,IRX,(PRI%Ascan(IRX,IRG),PRI%AmpdB(IRX,IRG),DpR*PRI%Phase(IRX,IRG), IRX=1,8)
ENDDO
!
100 FORMAT (A1,A4,A5,32(A7,I1))
101 FORMAT (2I5,32F8.1)
END SUBROUTINE AMPHASE
