#!/bin/sh
#
# cable_calibration -- plot amplitude and phase calibrations from Hermes VNA
# T. Bullett  Univerity of Colorado.
# 16Feb15
# Plots manual calibration data from multiple data sets.
# Assumes text data files have already been generated. 
#
# These are the specific data files.  The 0's are the reference values
# CAL is for Calibration system phase
# AMPC is for Preamp+Cable
UDTS="JB57N 2014 Calibration Field"
IMGFILE="JB57N_2014_CalField.png"
PLOTFILE="JB57N_2014_CalField.gnuplot"
#
CAL0="BD840_2014275215712_cal.dat"
CAL1="BD840_2014275215712_cal.dat"
CAL2="BD840_2014275221442_cal.dat"
CAL3="BD840_2014275221939_cal.dat"
CAL4="BD840_2014275223318_cal.dat"
CAL5="BD840_2014275223626_cal.dat"
CAL6="BD840_2014275224000_cal.dat"
CAL7="BD840_2014275224200_cal.dat"
CAL8="BD840_2014275224722_cal.dat"
#
AMPC0=$CAL0
AMPC1=$CAL1
AMPC2=$CAL2
AMPC3=$CAL3
AMPC4=$CAL4
AMPC5=$CAL5
AMPC6=$CAL6
AMPC7=$CAL7
AMPC8=$CAL8

   
#Plot the cal field data 
cat <<EOF  > $PLOTFILE
set title "$UDTS"
set xlabel "Frequency [MHz]"
set xrange [0:25]
set xtics 2
set ylabel "Amplitude [dB]"
set ytics 5
set mytics 5 
set yrange [40:80]
set y2label "Phase [Deg]"
set y2range [-3:2]
set y2tics 0.5
set grid 
set key outside right
set pointsize 0.5
set angle degrees 
unwrap(x)=atan2(sin(x),cos(x))
plot "<paste $CAL0 $CAL1"  using 6:9  with points pt 0 lc 0 title "A0",\
      ''  using 6:47  with points pt 1 lc 1 title "A1",\
      ''  using 6:(unwrap(\$48-\$10)) with points pt 1 lc 1 axis x1y2 title 'dP1',\
      "<paste $CAL0 $CAL2" using 6:47  with points pt 2 lc 2 title "A2",\
      '' using 6:(unwrap(\$48-\$10)) with points pt 2 lc 2 axis x1y2 title 'dP2',\
      "<paste $CAL0 $CAL3" using 6:47  with points pt 3 lc 3 title "A3",\
      '' using 6:(unwrap(\$48-\$10)) with points pt 3 lc 3 axis x1y2 title 'dP3',\
      "<paste $CAL0 $CAL4" using 6:47  with points pt 4  lc 4 title "A4",\
      '' using 6:(unwrap(\$48-\$10)) with points pt 4 lc 4 axis x1y2 title 'dP4',\
      "<paste $CAL0 $CAL5" using 6:47  with points pt 5  lc 5 title "A5",\
      '' using 6:(unwrap(\$48-\$10)) with points pt 5 lc 5 axis x1y2 title 'dP5',\
      "<paste $CAL0 $CAL6" using 6:47  with points pt 6  lc 6 title "A6",\
      '' using 6:(unwrap(\$48-\$10)) with points pt 6 lc 6 axis x1y2 title 'dP6',\
      "<paste $CAL0 $CAL7" using 6:47  with points pt 7  lc 7 title "A7",\
      '' using 6:(unwrap(\$48-\$10)) with points pt 7 lc 7 axis x1y2 title 'dP7',\
      "<paste $CAL0 $CAL8" using 6:47  with points pt 8  lc 8 title "A8",\
      '' using 6:(unwrap(\$48-\$10)) with points pt 8 lc 8 axis x1y2 title 'dP8'


set terminal png size 1280,1024
#set output "$IMGFILE-CalField.png"
#set term png size 1024,768
set output "$IMGFILE"
replot

exit

set title "Receive system data for $UDTS"
set y2range [-15:15]
set y2tics 5 
plot "<paste $AMPC0 $AMPC1"  using 6:37  with points pt 0 lc 0 title "A0",\
      ''  using 6:47  with points pt 1 lc 1 title "A1",\
      '' using 6:(unwrap(\$48-\$38)) with points pt 1 lc 1 axis x1y2 title 'dP1',\
      "<paste $AMPC0 $AMPC2" using 6:51  with points pt 2 lc 2 title "A2",\
      '' using 6:(unwrap(\$52-\$38)) with points pt 2 lc 2 axis x1y2 title 'dP2',\
      "<paste $AMPC0 $AMPC3" using 6:55  with points pt 3 lc 3 title "A3",\
      '' using 6:(unwrap(\$56-\$38)) with points pt 3 lc 3 axis x1y2 title 'dP3',\
      "<paste $AMPC0 $AMPC4" using 6:59  with points pt 4  lc 4 title "A4",\
      '' using 6:(unwrap(\$60-\$38)) with points pt 4 lc 4 axis x1y2 title 'dP4',\
      "<paste $AMPC0 $AMPC5" using 6:63  with points pt 5  lc 5 title "A5",\
      '' using 6:(unwrap(\$64-\$38)) with points pt 5 lc 5 axis x1y2 title 'dP5',\
      "<paste $AMPC0 $AMPC6" using 6:67  with points pt 6  lc 6 title "A6",\
      '' using 6:(unwrap(\$68-\$38)) with points pt 6 lc 6 axis x1y2 title 'dP6',\
      "<paste $AMPC0 $AMPC7" using 6:71  with points pt 7  lc 7 title "A7",\
      '' using 6:(unwrap(\$72-\$38)) with points pt 7 lc 7 axis x1y2 title 'dP7',\
      "<paste $AMPC0 $AMPC8" using 6:75  with points pt 8  lc 8 title "A8",\
      '' using 6:(unwrap(\$76-\$38)) with points pt 8 lc 8 axis x1y2 title 'dP8'
exit 

EOF

gnuplot -persist $PLOTFILE 
