#!/bin/sh
#
# calplot -- plot amplitude and phase calibrations from VIPIR
# T. Bullett  Univerity of Colorado.  March 2013
#
RIQFILE=$1
RG=${2:-19}
PLOTFILE="$HOME/tmp/calplot.gnu"
DATFILE="$(dirname $RIQFILE)/$(basename $RIQFILE .RIQ).dat"
IMGFILE="$(dirname $RIQFILE)/$(basename $RIQFILE .RIQ).png"
echo $DATFILE $IMGFILE 

riq_ionogram -s -G $RG -n1 1 -n2 20000 $RIQFILE > $DATFILE
cat <<EOF  > $PLOTFILE
set title "Calibration data for $RIQFILE"
set xlabel "Frequency [MHz]"
#set logscale x
set xrange [0.3:30]
set xtics 2
set ylabel "Amplitude [dB]"
set ytics 10
set yrange [0:90]
set y2label "Phase [Deg]"
set y2range [-30:30]
set y2tics 5
set grid 
set key outside right
set pointsize 0.5
set angle degrees
unwrap(x)=atan2(sin(x),cos(x))
set terminal png size 1280,1024
set output "$IMGFILE"
#set term wxt size 1280,1024
#     "$DATFILE" using 6:13 with points pt 2 lt 2 title "A2"

plot "$DATFILE" using 6:9  with points pt 1 lt 1 title "A1",\
      "$DATFILE" using 6:17 with points pt 3 lt 3 title "A3"
      
#     "$DATFILE" using 6:21 with points pt 4 lt 4 title "A4",\
#     "$DATFILE" using 6:25 with points pt 5 lt 5 title "A5",\
#     "$DATFILE" using 6:29 with points pt 6 lt 6 title "A6",\
#     "$DATFILE" using 6:33 with points pt 7 lt 7 title "A7",\
#     "$DATFILE" using 6:37 with points pt 8 lt 8 title "A8"
#     
#     "$DATFILE" using 6:(unwrap(\$10-\$10)) axis x1y2 with points pt 1 lt 1 title "P1-P1",\
#     "$DATFILE" using 6:(unwrap(\$14-\$10)) axis x1y2 with points pt 2 lt 2 title "P2-P1",\
#     "$DATFILE" using 6:(unwrap(\$18-\$10)) axis x1y2 with points pt 3 lt 3 title "P3-P1",\
#     "$DATFILE" using 6:(unwrap(\$22-\$10)) axis x1y2 with points pt 4 lt 4 title "P4-P1",\
#     "$DATFILE" using 6:(unwrap(\$26-\$10)) axis x1y2 with points pt 5 lt 5 title "P5-P1",\
#     "$DATFILE" using 6:(unwrap(\$30-\$10)) axis x1y2 with points pt 6 lt 6 title "P6-P1",\
#     "$DATFILE" using 6:(unwrap(\$34-\$10)) axis x1y2 with points pt 7 lt 7 title "P7-P1",\
#     "$DATFILE" using 6:(unwrap(\$38-\$10)) axis x1y2 with points pt 8 lt 8 title "P8-P1"

#plot "$DATFILE" using 6:9  with points pt 1 title "A1",\
#     "$DATFILE" using 6:13 with points pt 2 title "A2",\
#     "$DATFILE" using 6:(\$10-\$14) axis x1y2 with points pt 1 title "P1-P2"


exit 

EOF

gnuplot $PLOTFILE 
