#!/bin/bash
#
# daily_spectrum.sh 
# 
# Generate daily 3D spectrum plots
#
#     Terry Bullett  CIRES
#     23 Feb 2011
#     Version 0.7  
# 16Apr13 TWB  Added -E and -w options
# 21Jun13 TWB  Added -t option for real time use
#
# Command Line Parameters
# Optional switches
# -s station Select this station 
# -y year    Select this year  (must be 4 digits!)
# -d day     Select this day (must be 3 digits!)
# -r RIQARGS Optional arguments for riq-ionogram
# -D DATADIR  Over-rides the default data directory
# -E uses SAM files 
# -w Web.  Copies data to the web space 
# -t Today.  Uses data from today

# Requires
#    
# readriq Version 2.06+
#
APPNAME=daily_spectrum
TFMT='%F %T %Z'
YYYY=$(date -u +%Y)
DDD=$(date -u +%j)
LOGFILE="$HOME/log/$APPNAME-$YYYY-$DDD.log"
ERRLOG="$HOME/log/$APPNAME-$YYYY-$DDD.errlog"
TMPDIR="$HOME/tmp/$APPNAME"
#TMPDIR="/data/tmp/$APPNAME"
# For mirrion
DATADIR="/nfs/MIDS/data/public"
DATADIR="$(destination.sh LOCAL)/public"
WEBDIR="/data0/www/htdocs/daily_products"
#
REALTIME=$(date  -u +"$TFMT" )
mkdir -p $TMPDIR
# declare -i YEAR DAY 
#
STATIONLIST="$(hostname)"
YEARLIST=$(date -u +%Y --date yesterday)
DAYLIST=$(date -u +%j --date yesterday)

SAMFILES=""
WEBDATA=""
while getopts 'D:d:Ehr:s:ty:w' OPTION
do
   case $OPTION in
      D) DATADIR="$OPTARG"
         ;;
      E) SAMFILES="1"
         ;;
      d) DAYLIST="$OPTARG"
         ;;
      h) echo "$APPNAME  Version 0.20"
         echo "Generates daily spectrum plots"
         echo "Optional Arguments:"
	 echo "  -D  DATADIR  Location of the data"
	 echo "  -E  Use existing SAM files"
         echo "  -d  Day#. May be a list must be 3 digits Default is yesterday"
         echo "  -h  This message"
	 echo "  -r  RIQARGS  Optional argument(s) passed to riq_ionogram (via spectrumplot)"
         echo "  -s  Station. May be a list. Default is $(hostname)"
	 echo "  -t  Today.  Uses data from today.  Default is yesterday"
         echo "  -y  Year.  May be a list, must be 4 digits.  Default is yesterday"
	 echo "  -w  Web data. Copies data to the web space"
         exit 0
         ;; 
      r) RIQARGS="$OPTARG"
         ;; 
      s) STATIONLIST="$OPTARG"
         ;;
      t) YEARLIST=$(date -u +%Y)
         DAYLIST=$(date -u +%j)
         ;;
      y) YEARLIST="$OPTARG"
         ;;
      w) WEBDATA="1"
         ;;
   esac
done
# Remove the switches from the list.
shift $((OPTIND - 1))
#
#
PID=$$
#
for STATION in $STATIONLIST ; do
   for YEAR in $YEARLIST ; do
      for DAY in $DAYLIST ; do  
         REALTIME=$(date  -u +"$TFMT" )
         echo "$REALTIME - $APPNAME - INFO - Start processing for $STATION $YEAR $DAY"  >> $LOGFILE
#
         if [ -z $SAMFILES ] ; then
            INDIR="$DATADIR/$STATION"/individual/"$YEAR/$DAY"'/raw'
	 else
	    INDIR="$DATADIR/$STATION"/individual/"$YEAR/$DAY"'/misc'
         fi
#
         if [ ! -d $INDIR ] ; then
            echo "$REALTIME - $APPNAME - ERROR - Source directory $INDIR does not exist"  >> $LOGFILE
            exit -1
         fi 
         OUTDIR="$DATADIR/$STATION"/daily/"$YEAR/$DAY"'/misc'
         mkdir -p "$OUTDIR"
#        Generate the indvidual spectra.  This takes a 'long time'
         if [ -z $SAMFILES ] ; then
            find $INDIR -type f -iname "$STATION_*RIQ*" -exec spectrumplot.sh -r "$RIQARGS" {}  \; > /dev/null  2>>$ERRLOG  
	 fi
#
         SAMFILE="$OUTDIR/$STATION"_"$YEAR$DAY".sam
	 echo $SAMFILE
	 cat $INDIR/*.sam > $SAMFILE 2>>$ERRLOG
	 SPECTRA=$(spectrumplot-3D.sh -L $SAMFILE)
	 echo $SPECTRA 
#	 
	 OUTDIR="$DATADIR/$STATION"/daily/"$YEAR/$DAY"'/image'
         mkdir -p "$OUTDIR"
	 if [ -n $WEBDATA ] ; then
	    cp -a $SPECTRA $WEBDIR/ 2>>$ERRLOG 
	 fi 
         mv $SPECTRA $OUTDIR/  2>>$ERRLOG
#
#        Archve the individual spectral images and data plots
#	 OUTDIR="$DATADIR/$STATION"/individual/"$YEAR/$DAY"'/image'
#         mkdir -p "$OUTDIR"
#         mv $INDIR/*sam.png  $OUTDIR/  2>>$ERRLOG
#        Archive the SAM files if they were generated
         if [ -z $SAMFILES ] ; then
            find $INDIR -type f -iname '*.sam' -exec fillbuffer.sh -x {} LOCAL BACKUP  \; 2>>$ERRLOG
            find $INDIR -type f -iname '*sam.png' -exec fillbuffer.sh -x {} LOCAL BACKUP \; 2>>$ERRLOG
         fi
#	 
         REALTIME=$( date -u +"$TFMT")
         echo "$REALTIME - $APPNAME - INFO - Finished spectrum plot for $STATION $YEAR $DAY"  >> $LOGFILE
      done  # Days
   done     # Years
done        # Stations

exit 0

