PROGRAM dump_headers
!
! Dump the SCT and first PCT from VIPIR Version 1.2 RIQ raw data files
!
! 17Dec15 TWB  Updated to handle Version2 of the SCT/PCT
!              Optional binary SCT & PCT dumps
!              Optional number of PCT to print

IMPLICIT NONE
INCLUDE 'type-param.f90'    ! Must come first
INCLUDE 'sct.f90'
INCLUDE 'pct.f90'
INCLUDE 'pri.f90'
!
TYPE(SCTtype):: SCT
TYPE(PCTtype):: PCT
TYPE(PRItype):: PRI
!
! Local Variables
CHARACTER(128)::INFILE,CLP 
LOGICAL INFOK,EOF,SKIP,BINARY
INTEGER K,NA,IPCT,NPCT,WORDFORMAT
INTEGER :: IU=1,FLIPHASE=0
REAL,PARAMETER:: VERSION=2.08
!
! Functions
LOGICAL:: READSCT,READPCT,READPRI
!
NPCT=1
BINARY=.FALSE.
SKIP=.FALSE.
!
! 17Dec15 Add command line parameters
!
! Read the command line for arguments
K = IARGC() 
! Filename must exist
IF (K.LT.1) THEN
   WRITE(*,*) "dump-headers - ERROR: Input file must be specified"
   CALL EXIT(-1)
ENDIF
DO NA = 1, K
   CALL GETARG(NA,CLP)
   IF (CLP.EQ.'-h') THEN
      WRITE(*,*)' useage: dump_headers {options} filename'
      WRITE(*,*)' '
      WRITE(*,'(A,F8.3)') 'Version: ',VERSION
      WRITE(*,*)'Dump the contents of the Sounding Control Table (SCT) and'
      WRITE(*,*)'Pulse Control Table (PCT) from the RIQ format file'
      WRITE(*,*)' '
      WRITE(*,*)' -b binary -- generate binary files of SCT and PCT, default=no'
      WRITE(*,*)' -n Number of PCT blocks to read.  -1=all, 0=none,default=1 '
      WRITE(*,*)' Filename must be provided on the command line.'
      RETURN
   ELSE IF (SKIP) THEN
      SKIP=.FALSE.
   ELSE IF (CLP.EQ.'-b') THEN
      BINARY=.TRUE.
   ELSE IF (CLP.EQ.'-n') THEN
      CALL GETARG(NA+1,CLP)
      READ(CLP,*) NPCT
      SKIP=.TRUE.
   ELSE
!    This is the input file name
     INFILE=CLP
   ENDIF
ENDDO  ! Command Line parsing
!
!     Check if input file exists
!
INQUIRE(FILE=INFILE,EXIST=INFOK)
IF (.NOT.INFOK) THEN
   WRITE(0,*) ' dump_headers - error - Missing input file'
   CALL EXIT(-1)
ENDIF

IF (NPCT.LT.0) NPCT=999999
OPEN(UNIT=IU, FILE=INFILE, FORM="UNFORMATTED", ACCESS="STREAM")

! Read the SCT
CALL ZeroSCT(SCT)
EOF=READSCT(IU,  SCT)
IF (EOF) CALL EXIT(1)
CALL FixSCTstrings(SCT)
CALL DumpSCT(SCT)
!
WORDFORMAT=SCT%receiver%word_format
write(*,*) WORDFORMAT
!
IF (BINARY) THEN
   OPEN(UNIT=2, FILE='dumpsct.bin', FORM="UNFORMATTED", ACCESS="STREAM")
   WRITE(UNIT=2) SCT
   CLOSE(UNIT=2)
ENDIF

IF (NPCT.EQ.0) CALL EXIT(0)
!
IF (BINARY) OPEN(UNIT=2, FILE='dumppct.bin', FORM="UNFORMATTED", ACCESS="STREAM")
!
DO WHILE ((.NOT.EOF).AND.(IPCT.LT.NPCT))
   CALL ZEROPCT(PCT)
   EOF=READPCT(IU,PCT)
   IPCT=IPCT+1
   IF(EOF) CYCLE
   CALL FixPCTstrings(PCT)
   CALL DumpPCT(PCT)
   IF (BINARY) WRITE(2) PCT
!  Copy relevant elements from SCT and PCT to the PRI Structure
   CALL SCTPCT2PRI(SCT,PCT, PRI)
!  Over-ride number of range gates in the SCT by the command line
   EOF=READPRI(IU,FLIPHASE,WORDFORMAT,  PRI) ! skips the data 
ENDDO

CLOSE(UNIT=2)
CLOSE(UNIT=IU)
!
END PROGRAM dump_headers
