SUBROUTINE DumpPRI(DEBUG,DUMP,BLANKA,BLANKP,IPRI,PRI)
!
! T. Bullett
! University of Colorado
! 24Dec15 Returning from Antarctica
!
! Perform the output of the data in the PRI in numerous contents and formats
! Removed from the riq_ionogram code for easier maintenance, I hope.
!
! "To give Glory to God by exploring His universe with reverence"
!
USE misc_utils
IMPLICIT NONE
INCLUDE 'type-param.f90'! Global Types and parameter definitions  
INCLUDE 'pct.f90'
INCLUDE 'pri.f90'
!
! Passed arguments
LOGICAL,INTENT(IN)::DEBUG,DUMP,BLANKA,BLANKP
INTEGER,INTENT(IN)::IPRI
TYPE(PRItype),INTENT(IN) :: PRI
!
! Local Variables
INTEGER::I,IRX,IASCAN,IRNG,ISTACK,NR1,NR2,IPREF
REAL::PREF
LOGICAL::PREL
!
! Apply range gate limits
IF (PRI%RLIMIT) THEN
   NR1=PRI%RGT1
   NR2=PRI%RGT2
ELSE IF (PRI%GATESELECT) THEN
   NR1=PRI%IRGATE
   NR2=NR1
ELSE 
   NR1=1
   NR2=PRI%GateCount
ENDIF
!

! Relative phase
PREF=0.0
IPREF=PRI%PHASEREF
PREL=(IPREF.NE.0)
!
IF (DEBUG) WRITE(*,*) 'DumpPRI -- NR1=',NR1,' NR2=',NR2,'IPREF=',IPREF
!
! The standard raw format
IF (PRI%RAW) THEN
   WRITE(*,100) 'PRI','Rx','Rgt','Ascan','Stack','UT_Time','dt','Freq','I','Q','M','P'
   DO IRX=1,PRI%ReceiverCount
!     Determine if this receiver is masked out
      IF (.NOT.BTEST(PRI%MASKRX, IRX-1)) CYCLE
      IASCAN=PRI%ReceiverCount*(IPRI-1)+IRX !  Is this still accurate and was it ever meaningful? 
      DO IRNG=NR1,NR2
         ISTACK=PRI%GateCount*(IRX-1)+IRNG
         IF(PREL) PREF=PRI%Phase(IPREF,IRNG) 
         WRITE(*,101) IPRI,IRX,IRNG,IASCAN,ISTACK,PRI%UTtime, &
                     US*(PRI%RelativeTime+PRI%GateStart+PRI%GateStep*(IRNG-1)), &
                     KHZ*PRI%Frequency, PRI%Ascan(IRX,IRNG), &
                         PRI%AmpdB(IRX,IRNG),DpR*UNWRAP(PRI%Phase(IRX,IRNG)-PREF)
       ENDDO       ! Range Gates
       IF(BLANKA) WRITE(*,*)
    ENDDO          ! Receivers
    IF(BLANKP) WRITE(*,*)
!
! Stacked raw format, all receivers on a single line.  Ignores receiver masking
ELSE IF (PRI%STACKRAW) THEN
   WRITE(*,110) 'PRI','Rgt','Ascan','UT_Time','dt','Freq',('I',I,'Q',I,'M',I,'P',I,I=1,8)
   IASCAN=PRI%ReceiverCount*(IPRI-1)
   DO IRNG=NR1,NR2
      IF(PREL) PREF=PRI%Phase(IPREF,IRNG) 
      WRITE(*,111) IPRI,IRNG,IASCAN,PRI%UTtime, &
            US*(PRI%RelativeTime+PRI%GateStart+PRI%GateStep*(IRNG-1)), KHZ*PRI%Frequency, &
            (PRI%Ascan(I,IRNG),PRI%AmpdB(I,IRNG),DpR*UNWRAP(PRI%Phase(I,IRNG)-PREF),I=1,8)
   ENDDO ! Range Gates
   IF(BLANKA) WRITE(*,*)
   IF(BLANKP) WRITE(*,*)
!
! Simple Interferometer Raw dump
ELSE IF (PRI%SIRAW) THEN 
!  Start migrating raw output to a format similar to ionogram data
   WRITE(*,112) 'IPRI','IRNG','UT_Time','dt','Freq','Range','Kx','Ky','Kz','Zenith','Azimuth','Pox','Poy','Rx','Ry'
   DO IRNG=NR1,NR2
      WRITE(*,113) IPRI, IRNG, PRI%UTtime+US*PRI%RGTime(IRNG), PRI%RGTime(IRNG), &
             KHZ*PRI%Frequency, KM*PRI%RGTime(IRNG), (PRI%VK(IRNG,I),I=1,3), &
             PRI%Zenith(IRNG),PRI%Azimuth(IRNG), &
             (PRI%Phase0(IRNG,I),I=1,2), (PRI%CorrC(IRNG,I),I=1,2)       
   ENDDO
   IF(BLANKA) WRITE(*,*)
   IF(BLANKP) WRITE(*,*)
ENDIF

RETURN

100 FORMAT ('#',A5,A4,3A7,A12,A14,A12,8(2A13,2A10))
101 FORMAT (I6,I4,3I7,F12.3,F14.7,F12.6,4(1X,F12.3,1X,F12.3,1X,F9.3,1X,F9.3))
110 FORMAT ('#',A5,2A7,A12,A14,A12,8(2(11X,A1,I1),2(8X,A1,I1)))
111 FORMAT (I6,2I7,F12.3,F14.7,F12.6,8(1X,F12.3,1X,F12.3,1X,F9.3,1X,F9.3))
112 FORMAT ('#',A5,A6,1X,A14,A8,A12,A8,  3A10,  16A10)
113 FORMAT (2I6,1X,F14.6,F8.1,F12.5,F8.1,3F10.4,2F10.2,2F10.2, 2F10.4, 10F10.2)

END SUBROUTINE DumpPRI
