SUBROUTINE DumpPRIPDF(DEBUG,DUMP,BLANKA,BLANKP,IPRI,PRI,  NAMP,NPHA,NTOTAL)
!
! T. Bullett
! University of Colorado
! 25Dec15 "Today in the town of David a Savior has been born to you; he is the Messaiah, the Lord" Luke2:11
!
! Based on DumpPRI
! Perform and dump Probability Distribution Functions on raw data.
! Merges DumpPRI and MPANOISE functions and applies to amplitude and phase
!
! "To give Glory to God by exploring His universe with reverence"
!
! Requires UNWRAP() from misc_utils
! constants from type-param
!
! The NAMP,NPHA arrays are totals over 
!
! Time to invent a new text file format that works with gnuplot 
!
USE misc_utils
IMPLICIT NONE
INCLUDE 'type-param.f90'! Global Types and parameter definitions  
INCLUDE 'pct.f90'
INCLUDE 'pri.f90'
!
! Passed arguments
LOGICAL,INTENT(IN)::DEBUG,DUMP,BLANKA,BLANKP
INTEGER,INTENT(IN)::IPRI
TYPE(PRItype),INTENT(IN) :: PRI
INTEGER,INTENT(INOUT),DIMENSION(MAXRX,-MAXBIN:MAXBIN):: NAMP,NPHA
INTEGER,INTENT(INOUT)::NTOTAL
!
! Local Variables
INTEGER::I,IRX,NRX,IASCAN,IRNG,ISTACK,NR1,NR2,IPREF,NSA,NEA,NSP,NEP,IX
REAL::PREF,AMIN,AMAX,DA,PMIN,PMAX,DP,X
LOGICAL::PREL
INTEGER,DIMENSION(MAXRX,-MAXBIN:MAXBIN):: NXA,NXP
REAL,DIMENSION(MAXRX):: AMPMAX,AMPMIN
INTEGER,DIMENSION(MAXRX):: MAXRGT,MINRGT
!
NRX= PRI%ReceiverCount   ! For convenience
!
! Apply range gate limits
IF (PRI%RLIMIT) THEN
   NR1=PRI%RGT1
   NR2=PRI%RGT2
ELSE IF (PRI%GATESELECT) THEN
   NR1=PRI%IRGATE
   NR2=NR1
ELSE 
   NR1=1
   NR2=PRI%GateCount
ENDIF
!
! Relative phase
PREF=0.0
IPREF=PRI%PHASEREF
PREL=(IPREF.NE.0)
!
! Compute PDF's of amplitudes and phases for each receiver
NXA=0   ! Zero all amplitude counts
DO IRX=1, NRX
!
!  Amplitude PDF
!  Determine the bin #'s for the limits.  
!  These are wired the same for the amplitude and phases to make the printout pretty
!
   AMIN = -180.0
   AMAX = 180.0
   DA =   1.0
   NSA = INT(AMIN/DA)
   NEA = INT(AMAX/DA)
!  Place the counts in the arrays
   I=0
   AMPMIN(IRX) =  1.0E30
   AMPMAX(IRX) = -1.0E30
   MAXRGT(IRX)=0
   MINRGT(IRX)=0
   DO IRNG=NR1,NR2
      X=PRI%AmpdB(IRX,IRNG)
      IF (X.GT.AMPMAX(IRX)) THEN
         AMPMAX(IRX)=X
         MAXRGT(IRX)=IRNG
      ENDIF
      IF (X.LT.AMPMIN(IRX)) THEN
         AMPMIN(IRX)=X
         MINRGT(IRX)=IRNG
      ENDIF 
      IX = NINT(X/DA)
      IX = MAX(MIN(IX,NEA),NSA)
      NXA(IRX,IX) = NXA(IRX,IX) + 1    ! PRI count
      NAMP(IRX,IX) = NAMP(IRX,IX) + 1  ! Total Count
      NTOTAL = NTOTAL + 1
   ENDDO  ! Range Gates
ENDDO ! Receivers
!
!  Phases
NXP=0   ! Zero all phase counts
DO IRX=1, NRX
!  Determine the bin #'s for the limits
   PMIN = -180
   PMAX = 180
   DP =   1.0
   NSP = INT(PMIN/DP)
   NEP = INT(PMAX/DP)
!  Place the counts in the arrays
   I=0
   DO IRNG=NR1,NR2
      IF(PREL) PREF=PRI%Phase(IPREF,IRNG)
      X=DpR*UNWRAP(PRI%Phase(IRX,IRNG)-PREF)
      IX = NINT(X/DP)
      IX = MAX(MIN(IX,NEP),NSP)
      NXP(IRX,IX) = NXP(IRX,IX) + 1    ! PRI Count
      NPHA(IRX,IX) = NPHA(IRX,IX) + 1  ! Total Count
   ENDDO  ! Range Gates
ENDDO ! Receivers

!  Simple dump
IF(DUMP) THEN 
   DO IX=NSP,NEP
      WRITE(*,*) IX, (NXA(IRX,IX),NXP(IRX,IX),IRX=1,NRX)
   ENDDO
   IF (BLANKA) WRITE(*,*)
   IF (BLANKP) WRITE(*,*)
ENDIF

RETURN


100 FORMAT ('#',A5,A4,3A7,A12,A14,A12,8(2A13,2A10))
101 FORMAT (I6,I4,3I7,F12.3,F14.7,F12.6,4(1X,F12.3,1X,F12.3,1X,F9.3,1X,F9.3))
110 FORMAT ('#',A5,2A7,A12,A14,A12,8(2(11X,A1,I1),2(8X,A1,I1)))
111 FORMAT (I6,2I7,F12.3,F14.7,F12.6,8(1X,F12.3,1X,F12.3,1X,F9.3,1X,F9.3))
112 FORMAT ('#',A5,A6,1X,A14,A8,A12,A8,  3A10,  16A10)
113 FORMAT (2I6,1X,F14.6,F8.1,F12.5,F8.1,3F10.4,2F10.2,2F10.2, 2F10.4, 10F10.2)

END SUBROUTINE DumpPRIPDF
