PROGRAM hackriq
!
!
! Hacks the RIQ format to perform various modifications.
! To be used for Good and not Evil!
! Only coded to modify the SCT/PCT errors, and at that, only the zero frequency values
! that are the bugs in the fixed frequency data.
!
! T Bullett
! University of Colorado Boulder
! 17Dec15
!

IMPLICIT NONE
INCLUDE 'sct.f90'
INCLUDE 'pct.f90'

INTEGER,PARAMETER::MAXRG=8182
INTEGER,PARAMETER::MAXRX=8

TYPE(SCTtype) SCT
TYPE(PCTtype) PCT

!
! Local Variables
CHARACTER(256)::INFILE,CLP,OUTFILE
LOGICAL INFOK,EOF,SKIP,TRIMRG,DEBUG
INTEGER :: IU=1,OU=2,IERR=0
INTEGER :: K,NA,IPRI,NUMPRI,IRG,NUMRGI,NUMRGO,NUMRX,IRX,RGT1,RGT2,BITLOSS
REAL:: VERSION=0.10
INTEGER(KIND=4)::II32(MAXRG,MAXRX),IQ32(MAXRG,MAXRX)
INTEGER(KIND=2)::II16(MAXRG,MAXRX),IQ16(MAXRG,MAXRX)
CHARACTER(LEN=32):: TimeStamp
!
! Functions
LOGICAL:: READSCT, READPCT
!
! Parse the command line
SKIP=.FALSE.
OUTFILE=''
OUTFILE=""
DEBUG=.FALSE.
BITLOSS=0
CALL FDATE(TimeStamp)
IF (DEBUG) WRITE(*,*) TIMESTAMP
!
! Read the command line for arguments
K = IARGC() 
! Filename must exist
IF (K.LT.1) THEN
   WRITE(*,*) "hackriq - ERROR: Input file must be specified"
   CALL EXIT(-1)
ENDIF
DO NA = 1, K
   CALL GETARG(NA,CLP)
   IF (CLP.EQ.'-h') THEN
      WRITE(*,*)' useage: hackriq {} filename'
      WRITE(*,*)' '
      WRITE(*,'(A,F8.3)') 'Version: ',VERSION
      WRITE(*,*)' Hack RIQ data to correct known bugs'
      WRITE(*,*)' -o {Outfile} Sets output file.  Default is *.RIQ -->  *.HIQ'
      WRITE(*,*)' Filename must be provided on the command line.'
      RETURN
   ELSE IF (SKIP) THEN
      SKIP=.FALSE.
   ELSE IF (CLP.EQ.'-b') THEN
      CALL GETARG(NA+1,CLP)
      READ(CLP,*) BITLOSS
      SKIP=.TRUE.
   ELSE IF (CLP.EQ.'-d') THEN
      DEBUG=.TRUE.
   ELSE IF (CLP.EQ.'-o') THEN
      CALL GETARG(NA+1,OUTFILE)
      SKIP=.TRUE.
   ELSE
!    This is the input file name
     INFILE=CLP
   ENDIF
ENDDO  ! Command Line parsing
!
! 
!  Check if input file exists
INQUIRE(FILE=INFILE,EXIST=INFOK)
IF (.NOT.INFOK) THEN
   WRITE(*,*) ' downgrade_riq - error - Missing input file'
   CALL EXIT(-1)
ENDIF
!
! Set default filename
NA=LEN_TRIM(OUTFILE)
K=LEN_TRIM(INFILE)
IF (NA.EQ.0) THEN
   IF (K.LE.4) THEN    
      OUTFILE='HACK.NIQ'  ! If the input file is too short
   ELSE
      OUTFILE=INFILE(1:K-4)//'.HIQ'
   ENDIF
ENDIF

WRITE(*,'(A)') TRIM(OUTFILE)
   
!
! Set values into the headers
!
CALL ZeroSCT(SCT)
!
OPEN(UNIT=IU, FILE=INFILE, FORM="UNFORMATTED", ACCESS="STREAM")
! Read the SCT
EOF=READSCT(IU,  SCT)
IF (EOF) CALL EXIT(1)
!
!
! For convenient reference.
NUMPRI=SCT%timing%pri_count
NUMRGI=SCT%timing%gate_count  !  Input number of range gates
NUMRX=SCT%receiver%rx_chan
!
! Monkey with the SCT range gate settings.
! You will break things.  This needs testing
!
SCT%frequency%user="PCT frequency corrected for fixed frequency mode "//TRIM(TIMESTAMP)  
!
OPEN(UNIT=OU,FILE=OUTFILE, FORM="UNFORMATTED", ACCESS="STREAM" )
WRITE(OU) SCT
 
DO IPRI = 1, NUMPRI 
   CALL ZeroPCT(PCT)
   EOF=READPCT(IU,  PCT)
   IF(EOF) CALL EXIT(1)
   IF(DEBUG) CALL DUMPPCT(PCT)
!  Fix errors in the PCT at this point
!  The zero-frequency problem
   IF (PCT%frequency.LT.100.0) THEN
      PCT%frequency=SCT%frequency%base_table(PCT%base_id)
   ENDIF 
   WRITE(OU) PCT
   IF(DEBUG) CALL DUMPPCT(PCT)
!  Read the whole PRI on the theory that less swapping between Input and Output is more efficient.
!  Dosen't use much ram anaway.
   DO IRG = 1, NUMRGI
      DO IRX=1,NUMRX
!        For V1 files only!!
         READ(IU,IOSTAT=IERR) II16(IRG,IRX),IQ16(IRG,IRX)
         IF (IERR.NE.0) THEN
            WRITE(0,*) "hackriq -- WARN -  unexpected end of file"
            CLOSE(IU)
            CLOSE(OU)
            CALL EXIT(-2)
         ENDIF
      ENDDO  ! Rx
   ENDDO ! Range Gates
!
! Output the raw data as it was read without modification
   DO IRG = 1, NUMRGI
      DO IRX=1,NUMRX
         WRITE(OU) II16(IRG,IRX),IQ16(IRG,IRX)
      ENDDO
   ENDDO 
!

!   ENDDO  ! Range Gates
ENDDO     ! PRIs
!
CLOSE(UNIT=IU)
CLOSE(UNIT=OU)

!
END PROGRAM hackriq

