SUBROUTINE InitIntercept(SCT,URSICODE, Intercept)
!
! Initialize the Intercept structure using values in the VIPIR SCT
!
! Terry Bullett
! University of Colorado Boulder
!
! 01Oct14 
!
! License:
! This software is the intellectual property of the author.
! Generous terms of use are likely if you ask nicely.
! 
!
IMPLICIT NONE
INCLUDE 'type-param.f90'! Global Types and parameter definitions  
INCLUDE 'sct.f90'       ! SCT
INCLUDE 'intercept.f90' ! Processed intercept structure
!
REAL,PARAMETER:: ONEDEG=PI/180.0
!
! Passed arguments
TYPE(SCTtype),INTENT(IN) :: SCT
CHARACTER(LEN=5),INTENT(IN):: URSICODE
TYPE(InterceptType),INTENT(OUT) :: Intercept
!
! Local Varables
INTEGER:: I,SYSTIME,ENDTIME,RUNTIME,RTM,RTS
INTEGER,DIMENSION(9)::TIMEVALUES
REAL::GateRangeStep,COVERAGE
REAL,PARAMETER :: km_per_ns = 0.5 * c / (1.0E+3*1.0E+9)  ! kilometers per nanosecond
!
! Station
Intercept%SCT=SCT
! URSI Code
IF (LEN_TRIM(URSICODE).GT.0) THEN
   Intercept%URSICODE=URSICODE
ELSE
   Intercept%URSICODE=SCT%station%ursi_id(1:5)
ENDIF
! Time
Intercept%Year=SCT%start_year
Intercept%DayNumber=SCT%start_daynumber
Intercept%Month=SCT%start_month
Intercept%Day=SCT%start_day
Intercept%Hour=SCT%start_hour
Intercept%Minute=SCT%start_minute
Intercept%Second=SCT%start_second 
Intercept%EpochTime=SCT%start_epoch
! Character17 time string
WRITE(Intercept%TimeString,104) Intercept%Year,Intercept%DayNumber,Intercept%Hour,Intercept%Minute,Intercept%Second
!
! Location
Intercept%Latitude = SCT%Station%rx_latitude
Intercept%Longitude= SCT%Station%rx_longitude
Intercept%Altitude = SCT%Station%rx_altitude
!
! Range gates
Intercept%PRI=SCT%Timing%pri
Intercept%RangeGateOffset=SCT%Timing%range_gate_offset
Intercept%GateCount=SCT%Timing%gate_count
Intercept%NRANGE=Intercept%GateCount
Intercept%GateStart=SCT%Timing%gate_start
Intercept%GateEnd=SCT%Timing%gate_end
Intercept%GateStep=SCT%timing%gate_step
GateRangeStep=1000.0*SCT%timing%gate_step*km_per_ns
!
! Receivers
Intercept%NRX=SCT%station%rx_count
! Frequency Values.  Even sweep frequency intercepts are single frequency observations
Intercept%Frequency=0.0
Intercept%NFREQ=1
Intercept%Duration=Intercept%PRI   ! Will change if we intrgrate multiple pulses.
Intercept%TuneType=SCT%Frequency%tune_type 
!
! Doppler default
Intercept%NDOPP=SCT%station%rx_count 
!
! Oscillator Errors
Intercept%TxOscError=0.0
Intercept%RxOscError=0.0
!
Intercept%Zenith=0.0
Intercept%ZenithVar=ONEDEG
Intercept%Azimuth=0.0
Intercept%AzimuthVar=ONEDEG
Intercept%VK=0.0
Intercept%VKVar=1.0

Intercept%Amplitude=0.0
Intercept%AmpVar=1.0
Intercept%Doppler=0.0
Intercept%DopVar=1.0

! Set the NetCDF attributes
! 22Feb15  ToDo -- Move this into a separate subroutine???
!           Duplication between Ionogram and Intercept objects
!
Intercept%Format_Version="1.10"
Intercept%NamingAuthority="gov.noaa.ngdc"
Intercept%MetadataLink="http://www.ngdc.noaa.gov/ionosonde/documentation/"
Intercept%Title="Ionosonde Data"
Intercept%Experiment="Passive Intercept"
Intercept%Instrument="Vertical Incidence Pulsed Ionospheric Radar"
Intercept%CdmDataType="Station"
Intercept%ProcessingLevel="Amplitude, Doppler, Angle-of-Arrival"
Intercept%Keywords="IONOSONDE RADAR"
Intercept%KeywordsVocabulary="http://gcmd.gsfc.nasa.gov/Resources/valids/archives/GCMD_Instrument_Keywords.pdf"
Intercept%StandardNameVocabulary="CF-1.0"
Intercept%MagneticModel="IGRF 10"
Intercept%Summary="This file contains intercetped signal data consisting of quantities computed from raw data"//&
         " over a radar PRI or Pulse Set for a single observation frequency. "//&
         " Quantities include, at a minimum, received signal strength."
Intercept%Comment=""
!
!
Intercept%Mode="Passive"
!
Intercept%Project="Global Ionospheric Specification and Forecast"
Intercept%Acknowledgment="Archived by NGDC"
Intercept%ContributorName="Terry Bullett"
Intercept%ContributorRole="raw data reduction software"
!
! Note:  Dip angle and Magnetic Latitude
!        tan(DIP) = 2*tan(MagLat)
Intercept%Station="UNKNOWN"
!  
IF (Intercept%URSICODE.EQ.'AA109') THEN
   Intercept%Station="Addis Ababa"
   Intercept%MagLat=2.19
   Intercept%MagLon=355.1
   Intercept%GyroFreq=0.85
   Intercept%MagDip=0.61
   Intercept%CreatorName="Gizaw Mengistu"
   Intercept%Institution="Addis Ababa University"
   Intercept%CreatorEmail="gizaw_mengistu@gmx.net"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="NOAA/NGDC"
   Intercept%PublisherEmail="ionosonde@noaa.gov"
   Intercept%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%License="Public Domain"
ELSEIF (Intercept%URSICODE.EQ.'BD840') THEN
   Intercept%Station="Boulder"
   Intercept%MagLat=48.6
   Intercept%MagLon=319.6
   Intercept%GyroFreq=1.29
   Intercept%MagDip=66.82
   Intercept%CreatorName="Terry Bullett"
   Intercept%Institution="NOAA National Geophysical Data Center"
   Intercept%CreatorEmail="Terry.Bullett@noaa.gov"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="NOAA/NGDC"
   Intercept%PublisherEmail="ionosonde@noaa.gov"
   Intercept%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%License="Public Domain"
ELSEIF (Intercept%URSICODE.EQ.'HAJ45') THEN
   Intercept%Station="Hanscom"
   Intercept%MagLat=51.7
   Intercept%MagLon=7.0
   Intercept%GyroFreq=1.4
   Intercept%MagDip=68.0
   Intercept%CreatorName="Cesar Valladares"
   Intercept%Institution="Boston College"
   Intercept%CreatorEmail="valladar@bc.ed"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="NOAA/NGDC"
   Intercept%PublisherEmail="ionosonde@noaa.gov"
   Intercept%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%License="Public Domain"
ELSEIF (Intercept%URSICODE.EQ.'JM91J') THEN
   Intercept%Station="Jicamarca"
   Intercept%MagLat=0.26
   Intercept%MagLon=355.1
   Intercept%GyroFreq=0.63
   Intercept%MagDip=0.51
   Intercept%CreatorName="Marco Millo"
   Intercept%Institution="Jicamarca Radio Observatory"
   Intercept%CreatorEmail="jchau@jro.igp.gob.pe"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="Jicamarca Radio Observatory"
   Intercept%PublisherEmail="jchau@jro.igp.gob.pe"
   Intercept%PublisherUrl="http://jicamarca.ece.cornell.edu/"
   Intercept%License="Public Domain"
ELSEIF (Intercept%URSICODE.EQ.'KI100') THEN
   Intercept%Station="Kisumu"
   Intercept%MagLat=-10.6
   Intercept%MagLon=35.0
   Intercept%GyroFreq=0.63
   Intercept%MagDip=-20.6
   Intercept%CreatorName="Andrew Odhiambo"
   Intercept%Institution="Maseno University"
   Intercept%CreatorEmail="andrewoduor22@yahoo.co.uk"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="NOAA/NGDC"
   Intercept%PublisherEmail="ionosonde@noaa.gov"
   Intercept%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%License="Public Domain"
ELSEIF (Intercept%URSICODE.EQ.'PM91J') THEN
   Intercept%Station="Puerto Maldonado"
   Intercept%MagLat=-0.83
   Intercept%MagLon=355.1
   Intercept%GyroFreq=0.61
   Intercept%MagDip=-1.66
   Intercept%CreatorName="C. E. Valladares"
   Intercept%Institution="Boston College"
   Intercept%CreatorEmail="valladar@bc.edu"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="Boston College"
   Intercept%PublisherEmail="valladar@bc.edu"
   Intercept%PublisherUrl="http://www.bc.edu/research/isr/"
   Intercept%License="Per NSF LISN policy"
ELSEIF (Intercept%URSICODE.EQ.'PM91K') THEN
   Intercept%Station="Puerto Maldonado"
   Intercept%MagLat=-0.83
   Intercept%MagLon=355.1
   Intercept%GyroFreq=0.61
   Intercept%MagDip=-1.66
   Intercept%CreatorName="C. E. Valladares"
   Intercept%Institution="Boston College"
   Intercept%CreatorEmail="valladar@bc.edu"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="Boston College"
   Intercept%PublisherEmail="valladar@bc.edu"
   Intercept%PublisherUrl="http://www.bc.edu/research/isr/"
   Intercept%License="Per NSF LISN policy"
ELSEIF (Intercept%URSICODE.EQ.'SJJ18') THEN
   Intercept%Station="San Juan"
   Intercept%MagLat=26.1
   Intercept%MagLon=319.6
   Intercept%GyroFreq=0.92
   Intercept%MagDip=44.4
   Intercept%CreatorName="Terry Bullett"
   Intercept%Institution="NOAA National Geophysical Data Center"
   Intercept%CreatorEmail="Terry.Bullett@noaa.gov"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="NOAA/NGDC"
   Intercept%PublisherEmail="ionosonde@noaa.gov"
   Intercept%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%License="Public Domain"
ELSEIF (Intercept%URSICODE.EQ.'TZJ2J') THEN
   Intercept%Station="Tupiza"
   Intercept%MagLat=-11.0
   Intercept%MagLon=355.1
   Intercept%GyroFreq=0.61
   Intercept%MagDip=-21.2
   Intercept%CreatorName="C. E. Valladares"
   Intercept%Institution="Boston College"
   Intercept%CreatorEmail="valladar@bc.edu"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="Boston College"
   Intercept%PublisherEmail="valladar@bc.edu"
   Intercept%PublisherUrl="http://www.bc.edu/research/isr/"
   Intercept%License="Per NSF LISN policy"
ELSEIF (Intercept%URSICODE.EQ.'WI937') THEN
   Intercept%Station="Wallops Island"
   Intercept%MagLat=48.0
   Intercept%MagLon=0.8
   Intercept%GyroFreq=1.24
   Intercept%MagDip=65.22 
   Intercept%CreatorName="Terry Bullett"
   Intercept%Institution="NASA Wallops Island Flight Facility"
   Intercept%CreatorEmail="Terry.Bullett@noaa.gov"
   Intercept%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%PublisherName="NOAA/NGDC"
   Intercept%PublisherEmail="ionosonde@noaa.gov"
   Intercept%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Intercept%License="Principle Investigator Permission"
ENDIF
!
! NGDC required metadata
Intercept%Conventions="_Coordinates"
Intercept%MetadataConventions="UNIDATA Dataset Discovery v1.0"
! Coverage area is set to a default +/- 0.1 degree from the receiver location
! 20 to 500 km fixed altitide
COVERAGE=0.1
WRITE(Intercept%GeospatialLatMin,100) Intercept%Latitude  - COVERAGE
WRITE(Intercept%GeospatialLatMax,100) Intercept%Latitude  + COVERAGE
Intercept%GeospatialLatUnits="degrees"
Intercept%GeospatialLatResolution="none"
WRITE(Intercept%GeospatialLonMin,100) Intercept%Longitude - COVERAGE
WRITE(Intercept%GeospatialLonMax,100) Intercept%Longitude + COVERAGE
Intercept%GeospatialLonUnits="degrees"
Intercept%GeospatialLonResolution="none"
Intercept%GeospatialVerticalMin="20"
Intercept%GeospatialVerticalMax="500"
Intercept%GeospatialVerticalResolution="variable"
Intercept%GeospatialVerticalUnits="kilometers"
Intercept%GeospatialVerticalpositive="up"

! Start and End Times
WRITE(Intercept%TimeCoverageStart,101) Intercept%Year,Intercept%Month,Intercept%Day,Intercept%Hour,Intercept%Minute,Intercept%Second
RUNTIME=(Intercept%SCT%timing%pri*Intercept%SCT%timing%pri_count)/1000000
ENDTIME=Intercept%EpochTime+RUNTIME
CALL GMTIME(ENDTIME, TIMEVALUES)
TIMEVALUES(6)=TIMEVALUES(6)+1900  ! Years
TIMEVALUES(5)=TIMEVALUES(5)+1     ! Months
WRITE(Intercept%TimeCoverageEnd,101) TIMEVALUES(6),TIMEVALUES(5),TIMEVALUES(4),TIMEVALUES(3),TIMEVALUES(2),TIMEVALUES(1)
RTM=RUNTIME/60
RTS=MOD(RUNTIME,60)
WRITE(Intercept%TimeCoverageDuration,103) RTM,RTS
Intercept%TimeCoverageResolution="none"
!
! Timestamps.
SYSTIME=TIME()
CALL GMTIME(SYSTIME, TIMEVALUES)
TIMEVALUES(6)=TIMEVALUES(6)+1900  ! Years
TIMEVALUES(5)=TIMEVALUES(5)+1     ! Months
WRITE(Intercept%DateCreated,101) TIMEVALUES(6),TIMEVALUES(5),TIMEVALUES(4),TIMEVALUES(3),TIMEVALUES(2),TIMEVALUES(1)
Intercept%DateModified=Intercept%DateCreated
Intercept%DateIssued=Intercept%DateCreated
!
! Identifier
WRITE(Intercept%Identifier,102) Intercept%URSICODE,Intercept%Year,Intercept%Daynumber,Intercept%Hour,Intercept%Minute, &
                                Intercept%Second

RETURN
100 FORMAT (F10.3)
! ISO 8601 time format
101 FORMAT (I4.4,'-',I2.2,'-',I2.2,'T',I2.2,':',I2.2,':',I2.2,'Z')
102 FORMAT ('ionogram.'A5,'_',I4.4,I3.3,3I2.2)
103 FORMAT ('TM',I2.2,'S',I2.2)
104 FORMAT (I4.4,1X,I3.3,1X,I2.2,':',I2.2,':',I2.2) 

END
