!
! Define a structure for an passive Intercept that contains various computed data types
! and various metadata needed by netCDF format files.
! An Intercept is a receive only signal from a non-cooperating transmitter.
! It is assumed to be on continuously, not a pulsed transmission 
!
!  SCT Version 1.21
!
! Author: Tery Bullett,   University of Colorado CIRES
! 08 October 2014
! Linux using gfortran compiler
!
! License:
! This software is the intellectual property of the author.
! Please respect this.
! Generous terms of use are likely if you ask nicely.
!
! Purpose:
! "To give glory to God by exploring His universe with reverence"  
!
! History:
! 08Oct14 TWB  Started from ionogram object
! 20Feb15 TWV  Major updates
!
!
!
TYPE::InterceptType
TYPE(SCTtype):: SCT
!
! SCT Entries copied to the Intercept structure
CHARACTER(LEN=5)  :: URSICODE
CHARACTER(LEN=64) :: Station 
INTEGER           :: Year, DayNumber, Month, Day, Hour, Minute, Second
REAL              :: Latitude, Longitude, Altitude, StructVersion,UTtime
CHARACTER(LEN=17) :: TimeString
CHARACTER(LEN=128):: Readme, User
INTEGER           :: NRANGE, NFREQ, NDOPP, NRX
INTEGER(KIND=4)   :: EpochTime
REAL:: PRI, RangeGateOffset, GateStart, GateEnd, GateStep
INTEGER:: TuneType,FreqSteps, GateCount
!
! Computed or added information.  These are the properties of an intercept object
REAL:: MagLat,MagLon,MagDip,GyroFreq
REAL:: Frequency                    ! Nominal frequency of observation
REAL:: TxOscError                   ! Transmitter oscillator error, referenced to 10 MHz
REAL:: RxOscError                   ! Receiver oscillator error, referenced to 10 MHz
REAL:: ClockError                   ! Clock error in the time stamp.  [Seconds]
REAL:: Zenith, ZenithVar            ! Zenith and variation  
REAL:: Azimuth, AzimuthVar          ! Azimuth and variation 
REAL:: TK                           ! Total K vector magnitude
REAL,DIMENSION(3):: VK,VKVar        ! K Vector and Variabilites
REAL:: Amplitude, AmpVar            ! Amplitude and variablities 
REAL:: Doppler, DopVar              ! Doppler and variablities
CHARACTER(LEN=64):: Method          ! A description of the analysis method used (e.g. CPA, FFT, etc.)    
INTEGER:: NumAve                    ! # of samples averaged for this observation
INTEGER:: Statistic                 ! A flag indicating the choice of statistical estimators
                                    ! 0 = Central Moment (Mean, Standard Deviation)
                                    !  Others TBD 
REAL:: Duration                     ! Duration of the data set [seconds] ; nominally the PRI
INTEGER:: RG1, RG2                  ! Range Gate mask for processing, to eliminate transmitter and cal pulses.
!
! NetCDF Metadata Attributes
!  08Oct14 Ignored for the initial version.  ToDo
CHARACTER(LEN=16):: Format_Version,CdmDataType
CHARACTER(LEN=10):: GeospatialLatMin,GeospatialLonMin,GeospatialVerticalMin
CHARACTER(LEN=10):: GeospatialLatMax,GeospatialLonMax,GeospatialVerticalMax
CHARACTER(LEN=10):: GeospatialLatUnits,GeospatialLonUnits,GeospatialVerticalUnits
CHARACTER(LEN=10):: GeospatialLatResolution,GeospatialLonResolution,GeospatialVerticalResolution
CHARACTER(LEN=10):: GeospatialVerticalPositive,TimeCoverageDuration,TimeCoverageResolution
CHARACTER(LEN=24):: DateCreated,DateModified,DateIssued,TimeCoverageStart,TimeCoverageEnd
CHARACTER(LEN=64):: Identifier,NamingAuthority,Title,Experiment,Instrument,Mode,CreatorName,Institution,License
CHARACTER(LEN=64):: CreatorEmail,PublisherEmail,PublisherName,Conventions,MetadataConventions,MagneticModel,Keywords
CHARACTER(LEN=64):: Project,Acknowledgment,ProcessingLevel,ContributorName,ContributorRole
CHARACTER(LEN=128):: StandardNameVocabulary,CreatorUrl,PublisherUrl
CHARACTER(LEN=256):: History,Summary,Comment,MetadataLink,KeywordsVocabulary

END TYPE InterceptType
