SUBROUTINE LINREG(N,X,Y,    SLOPE,YINT,R)
!
!  Performs linear regression with a simple algorithm stolen from:
!
!  Programmer:   Dr. David G. Simpson
!                Department of Physical Science
!                Prince George's Community College
!                Largo, Maryland  20774
!
!  Date:         January 21, 2002
!
!  Language:     Fortran-90
!
!  Description:  This program performs a linear regression analysis for a set of 
!                data given as (x,y) pairs.  The output from
!                the program is the slope and y-intercept of the least-squares
!                best fit straight line through the data points.
!
! 18Feb15  TWB -- Adatped to my style and a subroutine 
! 
!
IMPLICIT NONE                                     ! no default data types
!
INTEGER,INTENT(IN):: N           ! number of data points
REAL,INTENT(IN):: X(N),Y(N)      ! input x,y data arrays
!
REAL,INTENT(OUT)::  SLOPE        ! y-intercept of least-squares best fit line
REAL,INTENT(OUT)::  YINT         ! slope of least-squares best fit line
REAL,INTENT(OUT)::  R            ! squared correlation coefficient
!
! Local Variables 
REAL::  SUMX   ! sum of x
REAL::  SUMX2  ! sum of x**2
REAL::  SUMXY  ! sum of x * y
REAL::  SUMY   ! sum of y
REAL::  SUMY2  ! sum of y**2
REAL::  RD     ! Denominators
INTEGER:: I
!
SLOPE=0.0
YINT=0.0
R=0.0
SUMX=0.0
SUMX2=0.0
SUMXY=0.0
SUMY=0.0
SUMY2=0.0
!
IF (N.LT.2) CALL EXIT(-1)
    
DO I=1,N                         ! loop for all data points
   SUMX  = SUMX + X(I)           ! compute sum of x
   SUMX2 = SUMX2 + X(I)*X(I)     ! compute sum of x**2
   SUMXY = SUMXY + X(I)*Y(I)     ! compute sum of x * y
   SUMY  = SUMY + Y(I)           ! compute sum of y
   SUMY2 = SUMY2 + Y(I)*Y(I)     ! compute sum of y**2
ENDDO
!
SLOPE=0.0
YINT=0.0
R=0.0
RD=(REAL(N)*SUMX2 - SUMX**2)
IF (RD.EQ.0.0) RETURN  ! Error Condition
SLOPE = (REAL(N)*SUMXY - SUMX*SUMY) / RD                ! compute slope
YINT = (SUMY*SUMX2 - SUMX*SUMXY) / RD                   ! compute y-intercept
RD=SQRT((SUMX2 - SUMX**2/REAL(N)) * (SUMY2 - SUMY**2/REAL(N)))
IF (RD.EQ.0) RETURN
R = (SUMXY-SUMX*SUMY/REAL(N)) /  RD                     ! Compute correlation coefficient
R=R*R                                                   ! Return R**2
!
RETURN
!
END SUBROUTINE LINREG
