SUBROUTINE PDF(XMIN,XMAX,NBIN,NX,X,  MODEBIN,MEDIANBIN,LQBIN,UQBIN,VAL,DF,CDF)
!
!  Calculate the Probability Distribution Function (PDF) of a table of numbers X(NX)
!  over the bounds (XMAX,XMIN) with NBIN bins.
!  The output is the Distribution Function DF(NBIN) and the Cumulative Distribution Function CDF(NBIN) 
!  with bin values VAL(NBIN) well as the bin with the most probable amplitude (MODEBIN) from the DF,
!  the median value bin (MEDIANBIN) and the Lower and Upper Quartile bins (LQBIN,UQBIN) from the CDF 
!  These are used by getting VAL(MEDIANBIN) and VAL(MODEBIN)
!
!  Author:  Terry Bullett   University of Colorado
!
!  08 October 2014
!     History:
!     08Oct14 TWB - Initial code based on F77 version of pdf.f
!
!
! Parameters
!
! Arguments: 
INTEGER,INTENT(IN):: NBIN,NX
REAL,INTENT(IN):: XMIN,XMAX,X(NX)
INTEGER,INTENT(OUT):: MODEBIN, MEDIANBIN,LQBIN,UQBIN
REAL,INTENT(OUT):: VAL(NBIN),DF(NBIN),CDF(NBIN)
! Local Variables
INTEGER::I,IX,NS,NE
REAL:: DX,VALMODE
!
!
DF=0
CDF=0
VAL=0
MEDIANBIN=0
MODEBIN=0
LQBIN=0
UQBIN=0

IF ((NX.LE.0).OR.(NBIN.LE.1)) RETURN
!
DX=(XMAX-XMIN)/REAL(NBIN-1)
IF (DX.EQ.0.0) RETURN 
!
DO I=1,NBIN
   VAL(I) = XMIN + DX*REAL(I-1)
ENDDO
! Determine the bin #'s for the limits
NS = 1
NE = INT((XMAX-XMIN)/DX)
! Do the counting
DO I=1,NX
   IX = NINT( (X(I)-XMIN-DX)/DX )  
   IX = MAX(MIN(IX,NE),NS)
   DF(IX) = DF(IX) + 1.0
ENDDO
!
! Normalize
DO I=1,NBIN
   DF(I)=DF(I)/REAL(NX)
ENDDO
!
! CDF and MEDIAN/MODE bins
CDF(1)=DF(1)
VALMODE=0.0
DO I=2,NBIN
   CDF(I)=DF(I)+CDF(I-1)
   IF ((CDF(I).GT.(0.25)).AND.(LQBIN.EQ.0)) LQBIN=I
   IF ((CDF(I).GT.(0.5)).AND.(MEDIANBIN.EQ.0)) MEDIANBIN=I
   IF ((CDF(I).GT.(0.75)).AND.(UQBIN.EQ.0)) UQBIN=I
!
   IF (DF(I).GT.VALMODE) THEN
      MODEBIN=I
      VALMODE=DF(I)
   ENDIF
ENDDO
! Force boundries for poorly defined ranges
LQBIN=MAX(MIN(LQBIN,NBIN),1)
UQBIN=MAX(MIN(UQBIN,NBIN),1)
MEDIANBIN=MAX(MIN(MEDIANBIN,NBIN),1)
MODEBIN=MAX(MIN(MODEBIN,NBIN),1)

!
RETURN
END SUBROUTINE PDF


