#!/bin/bash
#
# powerplot -- Generate power plots and SNR plots for Scion HF radar data
# using riq_ionogram 1.2 
#
# 8 independent plots, one for each receiver
# Version 2.04  17Jan10  Terry Bullett
#
# Raw data mode, no PRI processing
#
RIQFILE=$1
FRQSPAN="[*:*]"
RNGSPAN="[*:*]"
BFN=$(basename $RIQFILE .RIQ)
DIR=$(dirname $RIQFILE) 
TMPDIR="$HOME/tmp/riq"
export GDFONTPATH=/usr/share/fonts/truetype/msttcorefonts/

# Output and temp files
mkdir -p $TMPDIR
PLOTFILE=$TMPDIR/plot.gnu

RXLIST='1 2 3 4 5 6 7 8'
for RX in $RXLIST ; do
   TXTFILE="$DIR/$BFN-$RX"'_raw.dat'
   PWRIMG="$DIR/$BFN-$RX"'_RAW.png'
   echo $TXTFILE $PWRIMG 

#  This is a long process; do not repeat if already done
   if [ ! -f $TXTFILE  ] ; then 
      riq_ionogram -bp -r -n1 1 -n2 1024 -a $RX $RIQFILE > $TXTFILE
   fi 

   cat <<EOF > $PLOTFILE
set pm3d map corners2color c1
set grid lt 22 lw 1
set xrange $FRQSPAN
set xtics 8
set mxtics 1  
set yrange $RNGSPAN  
set ytics 50
set mytics 10   
set title "$BFN $2 Receiver $RX"
set xlabel "PRI"
set ylabel 'Range Gate'
set cbrange [0:120]
set cbtics 10 
set term png font arial 12 size 1024,768 crop 
set output "$PWRIMG"
splot "$TXTFILE" using 1:3:11 title "Power [dB]"
set output
exit

EOF

   gnuplot $PLOTFILE
# rm -f $PLOTFILE
done 
exit 0
