!
! Define the Pulse Repetition Interval structure for Ver 1 of RIQ file format
!
! T. Bullett    27Aug08   gfortran
!
! 14Feb09 TWB  Included PCT in the PRI
!              Moved RangeCal and RangeTable to the Ionogram() structure
!              NOTE:  The calling program must also include the definition of PCT
!                     before including this file.
!
! 10Aug11 TWB  Added arrival angle and Doppler data elements (and error estimates)
! 05Jul12 TWB  Added Peak Range Gate and Noise estimates to the PRI.
! 21Feb15 TWB  Added phase-based items(Zenith,Azimuth,etc)
! 24Dec15 TWB  Added control flags and parameters for PRI printing
!
!
TYPE :: PRItype
REAL :: Frequency
REAL :: UTtime,GateStart,GateStep,RelativeTime
REAL :: TK      !  Magnitude of K vector |k|
INTEGER :: PulsetLength, PulsetIndex, ReceiverCount, GateCount
! Control stuff
LOGICAL:: RAW,STACKRAW,SIRAW,GATESELECT,RLIMIT
INTEGER:: MASKRX,PHASEREF,IRGATE,RGT1,RGT2
TYPE (PCTtype) :: PCT
COMPLEX,DIMENSION(MAXRX,MAXRG):: Ascan                ! The raw I/Q values for each receiver/range
REAL,DIMENSION(MAXRX,MAXRG):: Amplitude, Phase, AmpdB ! Amplitude and phase values of I/Q
REAL,DIMENSION(MAXRG):: RGTime                        ! Range Gate Time
REAL,DIMENSION(MAXRG):: Zenith, Azimuth, Doppler      ! Azimuth and Zenith in radian spherical coordinates, Doppler in Hz
REAL,DIMENSION(MAXRG):: ZnErr, AzErr, DopErr          ! Error Bars on Azimuth, Zenith, Doppler
REAL,DIMENSION(MAXRG,3):: VK,VKErr                    ! The K vector and it's Error
INTEGER(KIND=1),DIMENSION(MAXRG):: Flag               ! A bad data flag.  0 is good, -1 is bad, others TBD
REAL,DIMENSION(MAXRG,2):: Phase0,CorrC                ! Phase0 and Correlation Coefficents in the X and Y directions
REAL,DIMENSION(MAXRX):: Noise,Peak
INTEGER,DIMENSION(MAXRX):: PeakRangeGate
END TYPE PRItype
