SUBROUTINE PRI2Intercept(DEBUG,RMIN,PRI,  Intercept,PRIStats)
!
! Perform statististics on the data in the PRI and place them in the Intercept object 
!
! Terry Bullett
! University of Colorado Boulder
!
! 22Feb15
!
! Linux using gfortran compiler
!
! License:
! This software is the intellectual property of the author.
! Generous terms of use are likely if you ask nicely.
! 
! "To give glory to God by exploring His universe with reverence"  
!
! Requires:
!
!
! Revision History
! 22Feb15 Version 0.10 -  Initial version  

!
IMPLICIT NONE
INCLUDE 'type-param.f90'! Global Types and parameter definitions  
INCLUDE 'sct.f90'       ! SCT
INCLUDE 'pct.f90'       ! SCT
INCLUDE 'pri.f90'       ! PRI
INCLUDE 'intercept.f90' ! Processed intercept structure
INCLUDE 'stats.f90'     ! Statistics Object
!
! Passed arguments
LOGICAL,INTENT(IN):: DEBUG
REAL,INTENT(IN)::RMIN    !   Mimimum correlation Coefficient to accept
TYPE(PRItype),INTENT(IN) :: PRI
TYPE(InterceptType),INTENT(OUT) :: Intercept
TYPE(STATtype):: PRIStats(MAXSTATS)   ! The low-level stats for this PRI
!
! Local Variables
INTEGER:: I,IRG,HH,MM,SS
REAL UTSEC,THETA,PHI
REAL,DIMENSION(3):: VKS   ! Vector K in Spherical coordinates
IF(DEBUG) WRITE(*,*) 'PRI2Intercept'
!
! Basic Stuff to transfer
Intercept%Frequency = PRI%Frequency
Intercept%TK = PRI%TK
!
! The PRI%Time is UT seconds of the day and includes the range gate time
UTSEC=PRI%UTtime
HH=INT(UTSEC/86400.)      ! Seconds per hour
Intercept%Hour=HH
UTSEC = UTSEC -REAL(86400*HH)
MM=INT(UTSEC/3600.)       ! Seconds per Minute
Intercept%Minute=MM
UTSEC = UTSEC - REAL(3600*MM) 
SS=INT(UTSEC)
Intercept%Second=SS
WRITE(Intercept%TimeString,104)  Intercept%Year,Intercept%DayNumber,HH,MM,SS

Intercept%UTtime=PRI%UTtime

! Determine the type of processing.  
! This does all the statisitics on the AoA and Doppler data in the PRI
!
!Work-In-Progress CALL PRI2Stat(DEBUG,PRI,   PRIStats)
!
!   Select which statisitic to represent the data set
!
IF (Intercept%Statistic.EQ.0) THEN   ! Perform central moment (Mean and Std Deviation) analysis on the K vector
Intercept%NumAve=0
Intercept%VK=0.0
   DO IRG=Intercept%RG1,Intercept%RG2
      IF (PRI%CorrC(IRG,1)*PRI%CorrC(IRG,2) .LT. RMIN) CYCLE                !  Reject data with large Rx*Ry
      Intercept%NumAve = Intercept%NumAve + 1
      DO I=1,3 
         Intercept%VK(I) = Intercept%VK(I) + PRI%VK(IRG,I)
      ENDDO 
   ENDDO
   IF(Intercept%NumAve.GT.0) THEN
      Intercept%VK = Intercept%VK/REAL(Intercept%NumAve)
   ENDIF
   Intercept%VKVar=0.0
   DO IRG=Intercept%RG1,Intercept%RG2
      DO I=1,3
        Intercept%VKVar(I) = (PRI%VK(IRG,I) - Intercept%VK(I))**2
      ENDDO
   ENDDO
   IF(Intercept%NumAve.GT.1) THEN
      Intercept%VKVar = SQRT(Intercept%VKVar)/(Intercept%NumAve-1)
   ELSE
      Intercept%VKVar = 1.0
   ENDIF
ELSE
   WRITE(*,*) 'PRI2Intercept -- ERROR -- Unspecified processing method'
ENDIF


! Map the K vector into spherical coordinates in antenna space
CALL XYZ2RTP(Intercept%VK, VKS) ! Convert unit vector AK to spherical AKS
THETA=VKS(2)
PHI=VKS(3)
! Rotate the spherical coordinates Theta,Phi to align with  geographic N/S/E/W
! giving Zenith and Azimuth
! For Wallops, this is a NOOP.
Intercept%Zenith = THETA
Intercept%Azimuth = PHI 


104 FORMAT (I4.4,1X,I3.3,1X,I2.2,':',I2.2,':',I2.2) 

RETURN
END SUBROUTINE PRI2Intercept

