#!/bin/bash
#
# rawplot -- plot amplitude and phase raw from VIPIR single range gate
# T. Bullett  Univerity of Colorado.  18Dec15
# Simple modification from improved calplot.sh
#
# Process command line options
export GDFONTPATH=/usr/share/fonts/truetype/msttcorefonts/
#
APPNAME=calplot
TFMT='%F %T %Z'
REALTIME=$(date -u +"$TFMT" )
YYYY=$(date -u +%Y)
DDD=$(date -u +%j)
LOGFILE="$HOME/log/$APPNAME-$YYYY-$DDD.log"
ERRLOG="$HOME/log/$APPNAME-$YYYY-$DDD.errlog"
TMPDIR="$HOME/tmp/$APPNAME"
mkdir -p $TMPDIR
PLOTFILE="$TMPDIR/calplot.gnu"
PID="$$"
#
declare -i LINEAR AOFF AOFFN POFF POFFN RX REFCHAN REFCOL ACOL PCOL AONLY PONLY N1 N2
# User-adjustable items.
SIZE='1280,1024'
LINEAR=$((1))
FRQSPAN='[*:*]'
AMPSCALE='[0:90]'
PHASCALE='[-180:180]'
N1=$((1))
N2=$((20000))
RIQARGS='-s -n1 '$N1' -n2 '$N2' ' 
EXTRA=''
RANGEGATE='19'
AOFF=$((0))
POFF=$((0))
AONLY=$((0))
PONLY=$((0))
TITLE="Raw"
RXLIST='1 2 3 4 5 6 7 8'
XTICS='1024'
MXTICS='4'
Y2TICS=45
MY2TICS=5
REFCHAN=$((1))   # The phase reference channel
#
while getopts 'a:A:f:G:hjkm:n:o:p:P:r:R:t:x:X:Y:' OPTION
do
   case $OPTION in
      a) AMPSCALE="$OPTARG"
         ;;
      A) AOFF=$(($OPTARG))
         ;;
      f) FRQSPAN="$OPTARG"
         ;;
      G) RANGEGATE="$OPTARG"
         ;;
      h)
         echo "rawplot-Version 2.08"
	 echo "Plot VIPIR calibration pulse data from a fixed range gate"
         echo "Optional switches"
         echo "-a AMPSCALE Set the amplitude scale,  Default= $AMPSCALE"
         echo "-A OFFSET  Set amplitude offset for each receiver.  Default=$AOFF"
         echo "-f FRQSPAN Change the frequency span.  Default= $FRQSPAN"
         echo "-G RANGEGATE  Select data from RANGEGATE"
         echo "-h Print this help message"
         echo "-j Amplitude only, default is amplitude and phase"
         echo "-k Phase only, default is amplitude and phase"
         echo "-m N1  First PRI to process"
         echo "-n N2  Last PRI to process" 
	 echo "-o OPTIONS Optional additional arguments for riq_ionogram."
	 echo "    Defaults are $RIQARGS -G $RANGEGATE"
         echo "-p PHASCALE Set the amplitude scale,  Default= $PHASCALE"
         echo "-P OFFSET  Set phase offset for each receiver.  Default= $POFF"
         echo "-r REFCHAN Set the phase reference channel.  Default= $REFCHAN"
         echo "-R RXLIST  Receive channel list.  Default= '$RXLIST' <- Rember to quote this list"
         echo "-t {title} Add to the title of the plot"
	 echo "-x EXTRA  Adds EXTRA string to the output files"
         echo "-X XTICS Set the z axis labels.  Default is $XTICS"
         echo "-Y Y2TICS Set the Y2 (phase) labels.  Default is $Y2TICS"
	 echo ""
	 exit 0 
	 ;;
      j) AONLY=$((1))    # Amplitude only
         ;;
      k) PONLY=$((1))    # Phase only
         ;;
      m) N1=$((OPTARG))
         ;;
      n) N2=$((OPTARG))
         ;; 
      o) RIQXARGS="$OPTARG"
         ;;
      p) PHASCALE="$OPTARG"
         ;;
      P) POFF=$(($OPTARG))
         ;;
      r) REFCHAN=$((OPTARG))
         ;;
      R) RXLIST="$OPTARG"
         ;; 
      t) TITLE="$OPTARG"
         ;;
      x) EXTRA="$OPTARG"
	 ;;
      X) X2TICS="$OPTARG"
         ;;
      Y) Y2TICS="$OPTARG"
         ;;
   esac
done
# Remove the switches from the list.  Remainder is a list of files to process
shift $((OPTIND - 1))
#
RIQARGS='-s -n1 '$N1' -n2 '$N2' '"$RIQXARGS" 
#db echo $RIQARGS 
#
# Time axis scaling.  Used to be Frequency
FSCALE='unset logscale x'

#
FILELIST="$@"
for INFILE in $FILELIST ; do 
   REALTIME=$(date -u +"$TFMT" )
   if [ -z $INFILE ] ; then 
      echo "$REALTIME - $APPNAME - FATAL - Input file is undefined" >> $LOGFILE 
      exit -1
   fi
   if [ ! -r $INFILE ] ; then 
      echo "$REALTIME - $APPNAME - FATAL - Input file $INFILE does not exist or is non-readable" >> $LOGFILE 
      exit 2
   fi
#
#  Determine if the data file is compressed.
#  ZIP compression is not supported, but it could be.
#  need to preserve the ZIP file.
#
   BZIP2=$(file $INFILE | grep bzip2)
   GZIP=$(file $INFILE | grep gzip)
#
#  Determine file names
   if [ -n "$BZIP2" ] ; then 
         RIQFILE="$(dirname $INFILE)/$(basename $INFILE .bz2)"
   elif [ -n "$GZIP" ] ; then
      RIQFILE="$(dirname $INFILE)/$(basename $INFILE .gz)"
   else
      RIQFILE="$INFILE"
   fi 
# decompress as needed
   if [ -n "$BZIP2" ] ; then
      echo "$REALTIME - $APPNAME - INFO - bzip2 decompress $INFILE"  >> $LOGFILE
      bunzip2 -qkfd "$INFILE" >> $ERRLOG 2>&1 
      EXS=$? 
      if [ $EXS != 0 ] ; then 
         echo "$REALTIME - $APPNAME - ERROR - bunzip2 failed with error $EXS"  >> $LOGFILE
         continue # to next file
      fi  
   elif [ -n "$GZIP" ] ; then
      echo "$REALTIME - $APPNAME - INFO - gzip decompress $INFILE" >> $LOGFILE
#     gzip does not allow to keep the compressed file. Force this.
      cp -a "$INFILE" $TMPDIR/ 
      gunzip -qfd "$INFILE" >> $ERRLOG 2>&1
      if [ $EXS != 0 ] ; then 
         echo "$REALTIME - $APPNAME - ERROR - gunzip failed with error $EXS"  >> $LOGFILE
         continue # to next file 
      fi  
      mv "$TMPDIR/$(basename $INFILE)" "$(dirname $INFILE)"
   fi
#
   REALTIME=$(date -u +"$TFMT" )
#
   BFN=$(basename $RIQFILE .RIQ)
   URSI=${BFN:0:5}
   source 'station_settings.sh' 
#
#  Determine the measurement time from the standard filename
   YEAR=${BFN:6:4}
   DAY=${BFN:10:3}
   HH=${BFN:13:2}
   MM=${BFN:15:2}
   SS=${BFN:17:2}
#
   DATESTRING="01Jan$YEAR $DAY days yesterday $HH:$MM:$SS"
   let OBSTIME=$(date -u +%s --date="$DATESTRING") >> $ERRLOG  2>&1  
   EXS=$?
   if [ $EXS != 0 ] ; then 
      echo "$REALTIME - $APPNAME - ERROR - Invalid date $DATESTRING"  >> $LOGFILE
      continue   # to next file
   fi  
   DATESTAMP=$(date -u +'%d%b%y'  --date="$DATESTRING" ) >> $ERRLOG  2>&1
   OBSDATE=$(date -u +'%Y %j %T %Z'  --date="$DATESTRING" ) >> $ERRLOG  2>&1 
#
   DATFILE="$(dirname $RIQFILE)/$(basename $RIQFILE .RIQ)""$EXTRA"'_raw.dat'
   IMGFILE="$(dirname $RIQFILE)/$(basename $RIQFILE .RIQ)""$EXTRA"'_raw.png'
   echo $DATFILE $IMGFILE 
#
   riq_ionogram $RIQARGS -G $RANGEGATE  $RIQFILE > $DATFILE
   EXS=$?
   if [ $EXS != 0 ] ; then 
      echo "$REALTIME - $APPNAME - ERROR - unsuccessful run of riq_ionogram"  >> $LOGFILE
      exit 3
   fi  
#
#  Generate the plot lines
   REFCOL=$((10+4*(REFCHAN-1)))  # The phase reference column number
   PLA=''
   PLP=''
   for RX in $RXLIST ; do
      ACOL=$((9+4*(RX-1)))
      PCOL=$((ACOL+1))
      AOS=""
      AOFFN=$((0))
      if (( AOFF )) ; then      # Apply amplitude offests to the data
         AOFFN=$((AOFF*(RX-1)))
         AOS='-'"$AOFFN"            # Needs to be a string
      fi 
      POS=""
      POFFN=$((0))
      if (( POFF )) ; then      # Apply amplitude offests to the data
         POFFN=$((POFF*(RX-1)))
         POS='-'"$POFFN"            # Needs to be a string
      fi 
#db      echo $RX $ACOL  $PCOL  $AOFF  $AOFFN $AOS 
      
      PLA="$PLA '$DATFILE'"' using 1:($'"$ACOL"'-'"$AOFFN"') with points pt '$RX' lt '$RX' title "A'$RX$AOS'", '
      PLP="$PLP '$DATFILE'"' using 1:(unwrap($'"$PCOL"'-$'"$REFCOL$POS"'-'"$POFFN"')) axis x1y2 with points pt '$RX' lt '$RX' title "P'$RX'-P'$REFCHAN$POS'", '
   done
#  Remove the last ', ' from the plot lines 
   PLA=${PLA:0:-2}
   PLP=${PLP:0:-2}
# 
   if (( $AONLY )) ; then 
      PLOTLINE='plot '"$PLA"
   elif (( $PONLY )) ; then 
      PLOTLINE='plot '"$PLP"
   else
#     Default is to plot both amplitude and phase 
      PLOTLINE='plot '"$PLA"', '$PLP
   fi 
#

cat <<EOF  > $PLOTFILE
set title "$STATION $OBSDATE $TIMESTAMP $TITLE" font "arial,14"
set xlabel "PRI[#]" font "arial,14"
$FSCALE
set xrange $FRQSPAN
set xtics $XTICS font "arial,14"
set mxtics $MXTICS
set ylabel "Amplitude [dB]" font "arial,14"
set ytics 10 font "arial,14"
set yrange $AMPSCALE
set y2label "Phase [Deg]" font "arial,14"
set y2range $PHASCALE
set y2tics $Y2TICS font "arial,14"
set my2tics $MY2TICS 
set grid x,y2
set label 1  "VIPIR  $BFN.RIQ" at screen 0.65,0.11 font "arial,10" 
set key outside right font "arial,10"
set pointsize 0.5
set angle degrees
unwrap(x)=atan2(sin(x),cos(x))
set terminal png size $SIZE
set output "$IMGFILE"
$PLOTLINE 
exit 

EOF

   gnuplot $PLOTFILE 
#   rm -f $PLOTFILE
#
#  Remove original files if decompression was desired
   if [ -n "$BZIP2" ] || [ -n "$GZIP" ] ; then   
      echo "$REALTIME - $APPNAME - INFO - removing decompressed file $RIQFILE"  >> $LOGFILE
      rm -f $RIQFILE 2>>$ERRLOG
   fi
#
   REALTIME=$(date -u +"$TFMT" )
   echo "$REALTIME - $APPNAME - INFO - Finished processing $INFILE"  >> $LOGFILE
done  # Each input file
exit 0
