PROGRAM riq_downgrade
!
!
! Downgrades the RIQ Version 2.x file format with 32 bit integers to the old
! RIQ version 1.2.
!
! T Bullett
! University of Colorado Boulder
! 07Dec15  Pearl Harbor Day
!
! Editorial:  In my opinion this is a terrble thing to do and I write this code
!             under protest as to the loss of scientific information the Mk2 VIPIR
!             can produce.  This process uninds several years of radar engineering development
!             for the convenience of one individual. 
!
! ToDo:  For anything more complex, have input and output SCT/PCT
!

IMPLICIT NONE
INCLUDE 'sct.f90'
INCLUDE 'pct.f90'

INTEGER,PARAMETER::MAXRG=8182
INTEGER,PARAMETER::MAXRX=8
INTEGER(KIND=4),PARAMETER::MASK16=Z'0000FFFF'

TYPE(SCTtype) SCT
TYPE(PCTtype) PCT

!
! Local Variables
CHARACTER(256)::INFILE,CLP,OUTFILE
LOGICAL INFOK,EOF,SKIP,TRIMRG,DEBUG
INTEGER :: IU=1,OU=2,IERR=0
INTEGER :: K,NA,IPRI,NUMPRI,IRG,NUMRGI,NUMRGO,NUMRX,IRX,RGT1,RGT2,BITLOSS
REAL:: VERSION=0.01
!
! These are the 16 bit data mapped into big endian
INTEGER(KIND=2)::II16(MAXRG,MAXRX),IQ16(MAXRG,MAXRX),IPHAS2,IQUAD2
INTEGER(KIND=4)::II32(MAXRG,MAXRX),IQ32(MAXRG,MAXRX),IPHAS4,IQUAD4


! These equivalanced arrays are used to swap the bytes in the I/Q bytes
! because these i86 systems use little endian and the data are in big endian
! In theory the TRANSFER() intrinsic can be used to do this, but it will be slower
! and the intinisic is obtuse.  But compilers complain about this ancient technology.
!
INTEGER(KIND=2),DIMENSION(2)::IPQ
INTEGER(KIND=1),DIMENSION(4)::IBP
EQUIVALENCE (IPQ(1),IBP(1))
!
 
!VOLUME=100.0, RANGE1=0.0, RANGE2=0.0, RANGE0=0.0

! Functions
LOGICAL:: READSCT, READPCT
!
! Parse the command line
SKIP=.FALSE.
OUTFILE=''
BITLOSS=16
RGT1=0
RGT2=0
OUTFILE=""
DEBUG=.FALSE.
TRIMRG=.FALSE.
!
! Read the command line for arguments
K = IARGC() 
! Filename must exist
IF (K.LT.1) THEN
   WRITE(*,*) "riq_downgrade - ERROR: Input file must be specified"
   CALL EXIT(-1)
ENDIF
DO NA = 1, K
   CALL GETARG(NA,CLP)
   IF (CLP.EQ.'-h') THEN
      WRITE(*,*)' useage: riq_downgrade {} filename'
      WRITE(*,*)' '
      WRITE(*,'(A,F8.3)') 'Version: ',VERSION
      WRITE(*,*)'Downgrade RIQ 2.x data into NIQ version 1.2 format'
      WRITE(*,*)'Most of these are not yet enabled'
      WRITE(*,*)' '
      WRITE(*,*)' -b bitloss  Number of right bit shifts to apply to 32 bit data'
      WRITE(*,*)'             Default=16, loose the 16 least significant bits'
      WRITE(*,*)' -d Debug mode'
      WRITE(*,*)' -o {Outfile} Sets output file.  Default is *.RIQ -->  *.NIQ'
      WRITE(*,*)' -r1 Lower range gate to keep, default=first'
      WRITE(*,*)' -r2 Upper range gate, default=last'
      WRITE(*,*)' Filename must be provided on the command line.'
      RETURN
   ELSE IF (SKIP) THEN
      SKIP=.FALSE.
   ELSE IF (CLP.EQ.'-b') THEN
      CALL GETARG(NA+1,CLP)
      READ(CLP,*) BITLOSS
      SKIP=.TRUE.
   ELSE IF (CLP.EQ.'-d') THEN
      DEBUG=.TRUE.
   ELSE IF (CLP.EQ.'-o') THEN
      CALL GETARG(NA+1,OUTFILE)
      SKIP=.TRUE.
   ELSE IF (CLP.EQ.'-r1') THEN
      CALL GETARG(NA+1,CLP)
      READ(CLP,*) RGT1
      SKIP=.TRUE.
   ELSE IF (CLP.EQ.'-r2') THEN
      CALL GETARG(NA+1,CLP)
      READ(CLP,*) RGT2
     SKIP=.TRUE.
   ELSE
!    This is the input file name
     INFILE=CLP
   ENDIF
ENDDO  ! Command Line parsing
!
! 
!  Check if input file exists
INQUIRE(FILE=INFILE,EXIST=INFOK)
IF (.NOT.INFOK) THEN
   WRITE(*,*) ' downgrade_riq - error - Missing input file'
   CALL EXIT(-1)
ENDIF
!
! Set default filename
NA=LEN_TRIM(OUTFILE)
K=LEN_TRIM(INFILE)
IF (NA.EQ.0) THEN
   IF (K.LE.4) THEN    
      OUTFILE='DOWNGRADE.NIQ'  ! If the input file is too short
   ELSE
      OUTFILE=INFILE(1:K-4)//'.NIQ'
   ENDIF
ENDIF

WRITE(*,'(A)') TRIM(OUTFILE)
   
!
! Set values into the headers
!
CALL ZeroSCT(SCT)
!
OPEN(UNIT=IU, FILE=INFILE, FORM="UNFORMATTED", ACCESS="STREAM")
! Read the SCT
EOF=READSCT(IU,  SCT)
IF (EOF) CALL EXIT(1)
!
IF (SCT%receiver%word_format .NE. 3) THEN
   WRITE(0,*) "riq_downgrade -- FATAL -  Receiver word format not supported"
   CLOSE (IU)
   CALL EXIT (-1)
ENDIF
!
! Set the range gates to keep and set rational bounds
IF (RGT1.NE.0) THEN
   TRIMRG=.TRUE.
   RGT1=MIN(MAX(1,RGT1),SCT%timing%gate_count)
ENDIF
IF (RGT2.NE.0) THEN
   TRIMRG=.TRUE.
   RGT2=MIN(MAX(1,RGT2),SCT%timing%gate_count)
ENDIF
IF (DEBUG) WRITE(*,100) 'RGT1=',RGT1,'RGT2=',RGT2
100 FORMAT (A,1X,I5,1X,A,1X,I5)
!
!
! For convenient reference.  NUMRG may change  
NUMPRI=SCT%timing%pri_count
NUMRGI=SCT%timing%gate_count  !  Input number of range gates
NUMRX=SCT%receiver%rx_chan

IF (TRIMRG.AND.(RGT2.LE.RGT1)) THEN
   WRITE(0,*) "riq_downgrade -- FATAL -  RGT2 must be greater than RGT1"
   CALL EXIT (-1)
ENDIF
!
! Monkey with the SCT range gate settings.  This needs testing
!
IF (TRIMRG) THEN
!  Really NIQ things up
   SCT%timing%gate_count = RGT2 - RGT1
   SCT%timing%gate_start = SCT%timing%gate_step * RGT1
   SCT%timing%gate_end = SCT%timing%gate_step * RGT2
   CONTINUE
ENDIF 
!

! Essential Changes
SCT%receiver%word_format=1
SCT%struct_version=1.2
NUMRGO=SCT%timing%gate_count        ! Number of output range gates
SCT%raw_data_size=2*2*NUMRX*NUMRGO  ! 2 bytes per value, I&Q, # receivers, # Range gates ri
!
!
OPEN(UNIT=OU,FILE=OUTFILE, FORM="UNFORMATTED", ACCESS="STREAM" )
WRITE(OU) SCT
 
DO IPRI = 1, NUMPRI 
   CALL ZeroPCT(PCT)
   EOF=READPCT(IU,  PCT)
   IF(EOF) CALL EXIT(1)
   WRITE(OU) PCT
!  Read the whole PRI on the theory that less swapping between Input and Output is more efficient.
!  Dosen't use much ram anaway.
   DO IRG = 1, NUMRGI
      DO IRX=1,NUMRX
         READ(IU,IOSTAT=IERR) II32(IRG,IRX),IQ32(IRG,IRX)
         IF (IERR.NE.0) THEN
            WRITE(0,*) "riq_downgrade -- WARN -  unexpected end of file"
            CLOSE(IU)
            CLOSE(OU)
            CALL EXIT(-2)
         ENDIF
!        Convert the data
         IPHAS4=II32(IRG,IRX)
         IPHAS2=INT(IAND(RSHIFT( IPHAS4, BITLOSS), MASK16)) 
         II16(IRG,IRX) = IPHAS2
         IQUAD4=IQ32(IRG,IRX)
         IQUAD2=INT(IAND(RSHIFT( IQUAD4, BITLOSS), MASK16)) 
         IQ16(IRG,IRX) = IQUAD2
         IF(DEBUG) WRITE(*,'(2I6,I3,1X,1Z8.8,1X,1Z4.4,1X,1Z8.8,1X,1Z4.4)') IPRI,IRG,IRX,IPHAS4,IPHAS2,IQUAD4,IQUAD2
      ENDDO  ! Rx
   ENDDO ! Range Gates
!
!  Now byte swap on output
   DO IRG = 1, NUMRGO
      DO IRX=1,NUMRX
         IPQ(1)=II16(IRG,IRX)
         IPQ(2)=IQ16(IRG,IRX)
         WRITE(OU) IBP(2),IBP(1),IBP(4),IBP(3)
      ENDDO
   ENDDO 
!

!   ENDDO  ! Range Gates
ENDDO     ! PRIs
!
CLOSE(UNIT=IU)
CLOSE(UNIT=OU)

!
END PROGRAM riq_downgrade

